@@ -201,11 +201,11 @@ class Irc(BotBase):
                         handle_exception()
                         continue
                     try:
-                        if int(ievent.cmnd) > 400: logging.error("< %s (%s)" % (res, self.cfg.name))
-                        elif int(ievent.cmnd) >= 300: logging.info("< %s (%s)" % (res, self.cfg.name))
+                        if int(ievent.cmnd) > 400: logging.error("< %s - %s" % (res, self.cfg.name))
+                        elif int(ievent.cmnd) >= 300: logging.info("< %s - %s" % (res, self.cfg.name))
                     except ValueError:
-                        if not res.startswith("PING") and not res.startswith("NOTICE"): logging.warn("< %s (%s)" % (res, self.cfg.name))
-                        else: logging.info("< %s (%s)" % (res, self.cfg.name))
+                        if not res.startswith("PING") and not res.startswith("NOTICE"): logging.warn("< %s - %s" % (res, self.cfg.name))
+                        else: logging.info("< %s - %s" % (res, self.cfg.name))
                     if ievent: self.handle_ievent(ievent)
                     timeout = 1
             except UnicodeError:
