@@ -1,4 +1,4 @@
-# fbf/botbase.py
+# fbf/lib/botbase.py
 #
 #
 
@@ -40,7 +40,6 @@ from fbf.lib.users import getusers
 from fbf.imports import gettornado
 
 tornado = gettornado()
-import tornado.ioloop
 
 ## basic imports
 
@@ -236,7 +235,7 @@ class BotBase(LazyDict):
         """ put output onto one of the output queues. """
         self.outqueue.put((nr, args))
 
-    def outputsizes(self):
+    def sizes(self):
         """ return sizes of output queues. """
         return (self.outqueue.qsize(), self.eventqueue.qsize())
 
