@@ -212,8 +212,10 @@ class Commands(LazyDict):
 
     def perms(self, cmnd):
         """ show what permissions are needed to execute cmnd. """
-        try: return self[cmnd].perms
-        except KeyError: return []
+        try: p =  self[cmnd].perms
+        except KeyError: p = []
+        if type(p) != list: p = [p,]
+        return p
 
     def whereis(self, cmnd):
         """ return plugin name in which command is implemented. """
