@@ -55,23 +55,29 @@ class Config(LazyDict):
         assert filename
         LazyDict.__init__(self, input, *args, **kw)
         self.origname = filename
+        self.logname = "config" + os.sep + filename
         self.origdir = ddir or getdatadir()
         self.setcfile(ddir, filename)
         self.jsondb = None
         if not self._comments: self._comments = {}
-        logging.info("fromfile - %s from %s" % (self.origname, whichmodule(2)))
+        logging.info("%s from %s" % (self.logname, whichmodule(2)))
         self.fromfile(self.cfile)
         self.init()
+        self.origdir = ddir or getdatadir()
+        self.setcfile(ddir, filename)
         if self.owner: logging.info("owner is %s" % self.owner)
         if "uuid" not in self: self.setuuid()
         if "cfile" not in self: self.cfile = self.setcfile(self.origdir, self.origname) 
         assert self.cfile
+        if not self.origdir in self.cfile: raise WrongFileName("%s not in %s" % (self.origdir, self.cfile))
+        assert self.cfile
 
     def setcfile(self, ddir, filename):
         self.filename = filename or 'mainconfig'
         self.datadir = ddir or getdatadir()
-        self.dir = self.datadir + os.sep + 'config'
-        self.cfile = self.dir + os.sep + filename
+        if self.datadir[-1] != os.sep: self.datadir += os.sep
+        self.dir = self.datadir + 'config'
+        self.cfile = self.dir + os.sep + self.filename
 
     def setuuid(self, save=True):
         logging.debug("setting uuid")
@@ -140,7 +146,7 @@ class Config(LazyDict):
         """ save config object to file. """
         if not filename: filename = self.cfile
         if not filename: raise Exception("no cfile found  - %s" % whichmodule(3))
-        logging.warn("saving %s" % filename)
+        logging.warn("%s saved" % self.logname)
         if filename.startswith(os.sep): d = [os.sep,]
         else: d = []
         for p in filename.split(os.sep)[:-1]:
@@ -359,7 +365,7 @@ mainconfig = None
 
 def getmainconfig(ddir=None):
     global mainconfig
-    if not mainconfig: mainconfig = Config("mainconfig", ddir=ddir)
+    if not mainconfig: mainconfig = Config("mainconfig", ddir)
     if "issaved" not in mainconfig: mainconfig.save()
     return mainconfig
 
