@@ -18,6 +18,12 @@ import sys
 class JsonBotError(Exception):
     pass
 
+class NoDbConnection(JsonBotError):
+    pass
+
+class NoDbResult(JsonBotError):
+    pass
+
 class CantLogon(JsonBotError):
     pass
 
