@@ -1,9 +1,13 @@
-# fbf/examples.py
+# fbf/lib/examples.py
 #
 #
 
 """ examples is a dict of example objects. """
 
+## fbf imports
+
+from fbf.utils.trace import whichplugin
+
 ## basic imports
 
 import re
@@ -14,10 +18,11 @@ class Example(object):
 
     """ an example. """
 
-    def __init__(self, descr, ex, url=False):
+    def __init__(self, descr, ex, url=False, modname=None):
         self.descr = descr
         self.example = ex
         self.url = url
+        self.modname = modname or whichplugin(2)
 
 ## Collection of exanples
 
@@ -33,10 +38,13 @@ class Examples(dict):
         """ return size of examples dict. """
         return len(list(self.keys()))
 
-    def getexamples(self):
+    def getexamples(self, disabled=None):
         """ get all examples in list. """
         result = []
         for i in list(self.values()):
+            if disabled:
+                for d in disabled:
+                    if d in i.modname: continue
             ex = i.example.lower()
             exampleslist = re.split('\d\)', ex)
             for example in exampleslist:
