@@ -1,4 +1,4 @@
-# fbf/fbfimport.py
+# fbf/lib/fbfimport.py
 #
 #
 
@@ -28,6 +28,12 @@ def _import(name):
         res = __import__(mm)
     return sys.modules[name]
 
+
+def silent_import(name):
+    from fbf.utils.exception import exceptionmsg
+    try: return _import(name)
+    except Exception as ex: logging.error(exceptionmsg())
+
 ## force_import function
 
 def force_import(name):
