@@ -13,7 +13,7 @@
 from fbf.utils.trace import whichmodule, calledfrom, callstack, where
 from fbf.utils.lazydict import LazyDict
 from fbf.utils.exception import handle_exception
-from fbf.utils.name import stripname
+from fbf.utils.name import stripname, reversename, stripdatadir
 from fbf.utils.locking import lockdec
 from fbf.utils.timeutils import elapsedstring
 from fbf.lib.callbacks import callbacks
@@ -86,19 +86,12 @@ class Persist(object):
         
     def __init__(self, filename, default=None, init=True, postfix=None):
         """ Persist constructor """
+        self.origname = filename
         if postfix: self.fn = str(filename.strip()) + str("-%s" % postfix)
         else: self.fn = str(filename.strip())
         self.lock = _thread.allocate_lock() # lock used when saving)
         self.data = LazyDict(default=default) # attribute to hold the data
-        try:
-            res = []
-            target = getdatadir().split(os.sep)[-1]
-            for i in self.fn.split(os.sep)[::-1]:
-                if target in i: break
-                res.append(i)
-            self.logname = os.sep.join(res[::-1])
-            if not self.logname: self.logname = self.fn
-        except: handle_exception() ; self.logname = self.fn
+        self.logname = reversename(stripdatadir(self.origname))
         self.countername = self.fn + "_" + "counter"
         if got:
             count = mc.get(self.countername)
