@@ -31,6 +31,9 @@ class TickLoop(TimedLoop):
         if self.counter % 60 == 0:
             event.type = event.cbtype = 'TICK60'
             callbacks.check(self.bot, event)
+        if self.counter % 10 == 0:
+            event.type = event.cbtype = 'TICK10'
+            callbacks.check(self.bot, event)
         maincfg = getmainconfig()
         t = maincfg.ticksleep or 1
         if self.counter % t == 0:
