@@ -102,7 +102,7 @@ def handle_admincallbacks(bot, ievent):
 cmnds.add('admin-callbacks', handle_admincallbacks, 'OPER')
 examples.add('admin-callbacks', 'show runtime callback table', 'admin-callbacks')
 
-## admin-userhostcache command
+## admin-userhostscache command
 
 def handle_userhostscache(bot, ievent):
     """ no arguments - show userhostscache of the bot the command is given on. """
@@ -121,6 +121,17 @@ def handle_loadall(bot, ievent):
 cmnds.add('admin-loadall', handle_loadall, 'OPER', threaded=True)
 examples.add('admin-loadall', 'load all plugins', 'admin-loadall')
 
+## admin-errors command
+
+def handle_adminerrors(bot, ievent):
+    """ no arguments - show logged errors (not exceptions). """
+    from fbf.utils.log import errors
+    if errors: ievent.reply("errors so far: ", errors)
+    else: ievent.reply("no errors")
+
+cmnds.add('admin-errors', handle_adminerrors, 'OPER')
+examples.add('admin-errors', 'show logged errors so far (not exceptions)', 'admin-errors')
+
 ## admin-makebot command
 
 def handle_adminmakebot(bot, ievent):
@@ -187,7 +198,7 @@ def handle_adminexceptions(bot, event):
 cmnds.add("admin-exceptions", handle_adminexceptions, ["OPER"])
 examples.add("admin-exceptions", "show exceptions raised", "admin-exceptions")
 
-## admin-debugon
+## admin-debugon command
 
 def handle_admindebugon(bot, event):
     """ no arguments - enable debug on a channel. """
@@ -198,7 +209,7 @@ def handle_admindebugon(bot, event):
 cmnds.add("admin-debugon", handle_admindebugon, ['OPER', ])
 examples.add("admin-debugon", "enable debug on a channel.", "admin-debugon")
 
-## admin-debugoff
+## admin-debugoff command
 
 def handle_admindebugoff(bot, event):
     """ no arguments - disable debug on a channel. """
@@ -263,4 +274,16 @@ def handle_adminfloodcontrol(bot, event):
 cmnds.add("admin-floodcontrol", handle_adminfloodcontrol, ['OPER', ])
 examples.add("admin-floodcontrol", "set the floodcontrol parameters of a user", "1) admin-floodcontrol dunker 20 2) admin-floodcontrol dunker 20 300 500")
 
+## admin-status command
+
+def handle_adminstatus(bot, event):
+    from fbf.lib.runner import allrunners
+    result = {}
+    for runner in allrunners:
+        result[runner.name] = runner.status(event.rest)
+    event.reply("current runner status: ", result)
+
+cmnds.add("admin-status", handle_adminstatus, "OPER")
+examples.add("admin-status", "show status of current runners", "admin-status")
+ 
 #### BHJTW 6-03-2012
\ No newline at end of file
