@@ -21,7 +21,7 @@ def handle_count(bot, ievent):
     #if ievent.prev: ievent.prev.wait()
     a = ievent.inqueue
     size = len(a)
-    ievent.reply(size)
+    ievent.reply(str(size))
 
 cmnds.add('count', handle_count, ['OPER', 'USER', 'GUEST'])
 examples.add('count', 'count nr of items', 'list ! count')
