@@ -36,7 +36,7 @@ examples.add('test', 'give test response',' test')
 
 def handle_source(bot, ievent):
     """ no arguments - show where to fetch the bot source. """ 
-    ievent.reply('see http://fbfbot.googlecode.com and http:///docs/fbfbot')
+    ievent.reply('see http://github.com/feedbackflow/fbfbot and http:///docs/fbfbot')
 
 cmnds.add('source', handle_source, ['USER', 'GUEST'])
 examples.add('source', 'show source url', 'source')
