@@ -5,6 +5,7 @@
 
 """ test plugin. """
 
+import fbf
 from fbf.utils.exception import exceptionmsg, handle_exception, exceptionevents, exceptionlist
 from fbf.lib.commands import cmnds
 from fbf.lib.examples import examples
@@ -12,8 +13,9 @@ from fbf.lib.eventbase import EventBase
 from fbf.lib.users import users
 from fbf.lib.threads import start_new_thread
 from fbf.utils.generic import waitforqueue, waitevents
-from fbf.lib.runner import cmndrunner, defaultrunner
+from fbf.lib.runner import cmndrunner, defaultrunner, threadrunner
 from fbf.lib.errors import NoSuchCommand
+from fbf import setglobal, getglobal
 
 ## basic imports
 
@@ -21,6 +23,7 @@ import time
 import random
 import copy
 import logging
+import queue
 
 ## defines
 
@@ -35,7 +38,8 @@ donot = ['relay', 'silent', 'spider', 'chan-token', 'bug', 'test-deadline', 'tes
 'test-plugs', 'cloneurl', 'clone', 'hb', 'rss-all', 'rss-get', 'rss-sync', 'rss-add', 'rss-register', 'rss-cloneurl', 'rss-scan']
 """
 
-donot = ['wiki', 'docmnd', 'exception', 'forward', 'admin', 'urlinfo', 'spider', 'fleet', 'validate', 'silent', 'test-plugs', 'markov-learn', 'loglevel', 'twitter', 'snarf', 'relay', 'reboot', 'quit']
+donot = ['tinyurl', 'deadline', 'imdb', 'wiki', 'translate', 'rss', 'docmnd', 'exception', 'forward', 'admin', 'urlinfo', 'spider', 'fleet', 'validate', 'silent', 'test-plugs', 'markov-learn', 'loglevel', 'twitter', 'snarf', 'relay', 'reboot', 'quit']
+disabled = ['tinyurl', 'imdb', 'wikipedia', 'translate', 'rss', 'forward', 'admin', 'urlinfo', 'spider', 'fleet', 'twitter', 'snarf', 'relay']
 errors = {}
 teller = 0
 
@@ -50,32 +54,31 @@ def dotest(bot, event, filter="", direct=False):
     global errors
     match = filter
     waiting = []
-    if True:
-        examplez = examples.getexamples()
-        random.shuffle(examplez)
-        for example in examplez:
-            if match and match not in example: continue
-            skip = False
-            for dont in donot:
-                if dont in example: skip = True
-            if skip: continue
-            teller += 1
-            e = bot.make_event(event.auth, event.channel, ";" + example, event, cbtype=event.cbtype)
-            e.speed = teller % 5
-            e.nodispatch = False
-            e.iscommand = True
-            try:
-                if direct: e.execute()
-                else: bot.put(e)
-            except NoSuchCommand as ex: logging.error("failed to find %s command" % str(ex)) ; continue
-            teller += 1
-            time.sleep(0.01)
-        event.reply("%s commands executed" % teller)
-    if errors:
-        event.reply("there are %s errors .. " % len(errors))
-        for cmnd, error in errors.items(): event.reply("%s - %s" % (cmnd, error))
-    for (event, msg) in exceptionevents: event.reply("EXCEPTION: %s - %s" % (event.txt,msg))
-    for msg in exceptionlist: event.reply("EXCEPTION: %s" % msg)
+    examplez = examples.getexamples(disabled)
+    random.shuffle(examplez)
+    for example in examplez:
+        if match and match not in example: continue
+        skip = False
+        for dont in donot:
+            if dont in example: skip = True
+        if skip: continue
+        teller += 1
+        e = bot.make_event(event.auth, event.channel, ";" + example, event, cbtype=event.cbtype)
+        e.speed = teller % 5
+        e.nodispatch = False
+        e.iscommand = True
+        e.globalerrors = True
+        try:
+            if direct: e.execute()
+            else:
+                bot.put(e)
+                waiting.append(e)               
+        except NoSuchCommand as ex: logging.error("failed to find %s command" % str(ex)) ; continue
+        except Exception as ex: altar.testerrors[example] = str(ex)
+        teller += 1
+        time.sleep(0.01)
+    for e in waiting: e.join()
+    event.reply("%s commands executed" % teller)
 
 ## test-plugs command
 
@@ -83,26 +86,39 @@ def handle_testplugs(bot, event):
     """ no arguments - test the plugins by executing all the available examples. """
     #bot.plugs.loadall(force=True)
     global teller
-    try: loop = int(event.args[0])
+    try: threaded = event.args[0]
+    except (ValueError, IndexError): threaded = 1
+    try: loop = int(event.args[1])
     except (ValueError, IndexError): loop = 1
-    try: threaded = event.args[1]
-    except (ValueError, IndexError): threaded = 0
     try: filter = event.args[2]
     except (ValueError, IndexError): filter = ""
     threads = []
     teller = 0
+    jobs = []
+    bot.plugs.disable(disabled)
     #event.dontclose = True
     for i in range(loop):
-        if threaded: threads.append(start_new_thread(dotest, (bot, event, filter)))
+        if threaded:
+            job = threadrunner.put(5, "dotest", dotest, bot, event, filter)
+            jobs.append(job)
         else: dotest(bot, event)
-    if threads:
-        for thread in threads: thread.join()
-    event.reply('%s tests run' % teller)
+    if jobs:
+        logging.error("%s jobs launched" % len(jobs))
+        for job in jobs:
+            if job: logging.info("trying to join %s" % str(job)) ; job.join()
+    testerrors = getglobal("testerrors")
+    if testerrors:
+        event.reply("there are %s test errors .. " % len(testerrors))
+        for cmnd, error in testerrors.items(): event.reply("%s - %s" % (cmnd, error))
+    else: event.reply("no errors")
+    errors = getglobal("errors")
     if errors:
         event.reply("there are %s errors .. " % len(errors))
         for cmnd, error in errors.items(): event.reply("%s - %s" % (cmnd, error))
     else: event.reply("no errors")
-    event.outqueue.append(None)
+    for (event, msg) in exceptionevents: event.reply("EXCEPTION: %s - %s" % (event.txt,msg))
+    for msg in exceptionlist: event.reply("EXCEPTION: %s" % msg)
+    #event.outqueue.append(None)
 
 cmnds.add('test-plugs', handle_testplugs, ['TEST', 'USER'], speed=3, threaded=True)
 examples.add('test-plugs', 'test all plugins by running there examples', 'test-plugs')
@@ -126,6 +142,8 @@ def handle_forcedexception(bot, ievent):
 cmnds.add('test-forcedexception', handle_forcedexception, 'TEST')
 examples.add('test-forcedexception', 'throw an exception as test', 'test-forcedexception')
 
+## test-forcedexceptionthreaded command
+
 def handle_forcedexceptionthreaded(bot, ievent):
     """ no arguments - raise a exception. """
     ievent.reply("raising exception")
@@ -199,7 +217,7 @@ def handle_testdeadline(bot, ievent):
 cmnds.add('test-deadline', handle_testdeadline, 'TEST')
 examples.add('test-deadline', "sleep 40 sec to trigger deadlineexceeded exception (GAE)", "test-deadline")
 
-## test-xhtml command
+## test-html command
 
 def handle_testhtml(bot, ievent):
     """ arguments: [<txt>] - test the html=True option to event.reply(). """
@@ -246,6 +264,8 @@ def handle_testre(bot, event):
 cmnds.add("test-re (.*)$", handle_testre, "TEST", regex=True)
 examples.add("test-re", "regular expression as command test", "test-re mekker")
 
+## test-multi command
+
 def handle_testmulti(bot, event):
     try: nr = int(event.rest)
     except: event.missing("<nr>") ; return
