@@ -16,12 +16,7 @@ from fbf.lib.callbacks import callbacks
 ##  pre_underauth_cb precondition
 
 def pre_underauth_cb(bot, ievent):
-    """ 
-        Only respond to the message like:
-        NOTICE AUTH :*** Your ident is disabled or broken, to continue
-        to connect you must type /QUOTE PASS 16188.
-
-    """
+    """ check if undernet auth in necessary. """
     args = ievent.arguments
     try: return (args[0] == 'AUTH' and args[-3] == '/QUOTE' and args[-2] == 'PASS')
     except Exception as ex: return False
