@@ -2,7 +2,7 @@
 #
 #
 
-""" provide todo related commands """
+""" provide todo related commands. """
 
 ## fbf imports
 
@@ -203,7 +203,7 @@ class TodoDb(object):
         result = db.execute(""" DELETE FROM todo WHERE name = %s """, (name, ))
         return result
 
-## defines
+## todo object
 
 todo = TodoDb()
 
@@ -220,7 +220,7 @@ def init():
     setalias('d', 'todo-done')
     setalias('tt', 'todo-time')
 
-# t command
+## todo command
 
 def handle_todo(bot, ievent):
     """ todo [<item>] .. show todo's or set todo item .. a time/date can be given. """
@@ -250,10 +250,10 @@ def handle_todo2(bot, ievent):
 cmnds.add('todo', handle_todo, 'USER')
 examples.add('todo', 'todo [<item>] .. show todo items or add a todo item', '1) todo 2) todo program the bot 3) todo 22:00 sleep')
 
-## t-done command
+## todo-done command
 
 def handle_tododone(bot, ievent):
-    """ t-done <listofnrs> .. remove todo items """
+    """ todo-done <listofnrs> .. remove todo items """
     if len(ievent.args) == 0: ievent.missing('<list of nrs>') ; return
     try:
         nrs = []
@@ -269,10 +269,10 @@ def handle_tododone(bot, ievent):
 cmnds.add('todo-done', handle_tododone, 'USER')
 examples.add('todo-done', 'remove items from todo list', '1) todo-done 1 2) todo-done 3 5 8')
 
-## t-chan command
+## todo-chan command
 
 def handle_chantodo(bot, ievent):
-    """ t-chan [<item>] .. show channel todo's or set todo item for channel"""
+    """ todo-chan [<item>] .. show channel todo's or set todo item for channel"""
     if ievent.rest: handle_chantodo2(bot, ievent) ; return
     todoos = todo.get(ievent.channel)
     saytodo(bot, ievent, todoos)
@@ -295,12 +295,12 @@ def handle_chantodo2(bot, ievent):
     ievent.reply('todo item %s added' % nr)
 
 cmnds.add('todo-chan', handle_chantodo, 'USER')
-examples.add('todo-chan', 't-chan [<item>] .. add channel todo', 'todo-chan fix bla')
+examples.add('todo-chan', 'todo-chan [<item>] .. add channel todo', 'todo-chan fix bla')
 
-## t-chandone command
+## todo-chandone command
 
 def handle_todochandone(bot, ievent):
-    """ t-chandone <listofnrs> .. remove channel todo item """
+    """ todo-chandone <listofnrs> .. remove channel todo item """
     if not ievent.rest: ievent.missing('<list of nrs>') ; return
     data = ievent.rest.split()
     try:
@@ -316,10 +316,10 @@ def handle_todochandone(bot, ievent):
 cmnds.add('todo-chandone', handle_todochandone, 'USER')
 examples.add('todo-chandone', 'todo-chandone <listofnrs> .. remove item from channel todo list', 'todo-chandone 2')
 
-## t-set command
+## todo-set command
 
 def handle_settodo(bot, ievent):
-    """ t-set <name> <txt> .. add a todo to another user's todo list"""
+    """ todo-set <name> <txt> .. add a todo to another user's todo list"""
     try:
         who = ievent.args[0]
         what = ' '.join(ievent.args[1:])
@@ -347,10 +347,10 @@ def handle_settodo(bot, ievent):
 cmnds.add('todo-set', handle_settodo, 'USER')
 examples.add('todo-set', 'set todo item of <nick>', 'todo-set dunker bot proggen')
 
-## t-get command
+## todo-get command
 
 def handle_gettodo(bot, ievent):
-    """ t-get <nick> .. get todo of another user """
+    """ todo-get <nick> .. get todo of another user """
     try: who = ievent.args[0]
     except IndexError: ievent.missing('<nick>') ; return
     userhost = getwho(bot, who)
@@ -366,10 +366,10 @@ def handle_gettodo(bot, ievent):
 cmnds.add('todo-get', handle_gettodo, ['USER', 'WEB'])
 examples.add('todo-get', 'todo-get <nick> .. get the todo list of <nick>', 'todo-get dunker')
 
-## t-time command
+## todo-time command
 
 def handle_todotime(bot, ievent):
-    """ t-time .. show time related todoos """
+    """ todo-time .. show time related todoos """
     name = getusers().getname(ievent.userhost)
     todoos = todo.timetodo(name)
     saytodo(bot, ievent, todoos)
@@ -377,7 +377,7 @@ def handle_todotime(bot, ievent):
 cmnds.add('todo-time', handle_todotime, 'USER')
 examples.add('todo-time', 'todo-time .. show todo items with time fields', 'todo-time')
 
-## t-week command
+## todo-week command
 
 def handle_todoweek(bot, ievent):
     """ todo-week .. show time related todo items for this week """
@@ -386,9 +386,9 @@ def handle_todoweek(bot, ievent):
     saytodo(bot, ievent, todoos)
 
 cmnds.add('todo-week', handle_todoweek, 'USER')
-examples.add('todo-week', 't-week .. todo items for this week', 'todo-week')
+examples.add('todo-week', 'todo-week .. todo items for this week', 'todo-week')
 
-## t-today command
+## todo-today command
 
 def handle_today(bot, ievent):
     """ todo-today .. show time related todo items for today """
@@ -399,7 +399,7 @@ def handle_today(bot, ievent):
 cmnds.add('todo-today', handle_today, 'USER')
 examples.add('todo-today', 'todo-today .. todo items for today', 'todo-today')
 
-## t-tomorrow command
+## todo-tomorrow command
 
 def handle_tomorrow(bot, ievent):
     """ todo-tomorrow .. show time related todo items for tomorrow """
@@ -422,12 +422,12 @@ def handle_tomorrow(bot, ievent):
     saytodo(bot, ievent, todoos)
 
 cmnds.add('todo-tomorrow', handle_tomorrow, 'USER')
-examples.add('todo-tomorrow', 't-tomorrow .. todo items for tomorrow', 'todo-tomorrow')
+examples.add('todo-tomorrow', 'todo-tomorrow .. todo items for tomorrow', 'todo-tomorrow')
 
-## t-setprio command
+## todo-setprio command
 
 def handle_setpriority(bot, ievent):
-    """ t-setprio [<channel|name>] <itemnr> <prio> .. show priority on todo item """
+    """ todo-setprio [<channel|name>] <itemnr> <prio> .. show priority on todo item """
     try: (who, itemnr, prio) = ievent.args
     except ValueError:
         try:
@@ -445,7 +445,7 @@ def handle_setpriority(bot, ievent):
 cmnds.add('todo-setprio', handle_setpriority, 'USER')
 examples.add('todo-setprio', 'todo-setprio [<channel|name>] <itemnr> <prio> .. set todo priority', '1) todo-setprio #dunkbots 2 5 2) todo-setprio owner 3 10 3) todo-setprio 2 10')
 
-## t-settime command
+## todo-settime command
 
 def handle_todosettime(bot, ievent):
     """ todo-settime [<channel|name>] <itemnr> <timestring> .. set time \
@@ -466,9 +466,9 @@ def handle_todosettime(bot, ievent):
     ievent.reply('time of todo %s set to %s' % (itemnr, time.ctime(ttime)))
 
 cmnds.add('todo-settime', handle_todosettime, 'USER')
-examples.add('todo-settime', 't-settime [<channel|name>] <itemnr> <timestring> .. set todo time', '1) todo-settime #dunkbots 2 13:00 2) todo-settime owner 3 2-2-2010 3) todo-settime 2 22:00')
+examples.add('todo-settime', 'todo-settime [<channel|name>] <itemnr> <timestring> .. set todo time', '1) todo-settime #dunkbots 2 13:00 2) todo-settime owner 3 2-2-2010 3) todo-settime 2 22:00')
 
-## t-getprio command
+## todo-getprio command
 
 def handle_getpriority(bot, ievent):
     """ todo-getprio <[channel|name]> <itemnr> .. get priority of todo item """
@@ -490,6 +490,8 @@ def handle_getpriority(bot, ievent):
 cmnds.add('todo-getprio', handle_getpriority, 'USER')
 examples.add('todo-getprio', 'todo-getprio [<channel|name>] <itemnr> .. get todo priority', '1) todo-getprio #dunkbots 5 2) todo-getprio 3')
 
+## saytodo function
+
 def saytodo(bot, ievent, todoos):
     """ output todo items of <name> """
     result = []
@@ -505,3 +507,5 @@ def saytodo(bot, ievent, todoos):
         if i.priority: res += "[%+d] " % i.priority
         result.append(res.strip())
     if result: ievent.reply("todolist of %s: " % ievent.nick, result, nritems=True)
+
+#### BHJTW 2-10-2012
