@@ -159,7 +159,7 @@ class BugTracker:
         except BugTrackerNotFound as e:
             ievent.reply('error: not found: %s' % e)
 
-    ## bug-show command
+    ## bug command
 
     def handle_show(self, bot, ievent):
         if len(ievent.args) != 1:
@@ -354,9 +354,7 @@ class GoogleCode(BugTracker):
         assert bugId.isdigit(), "bug id has to ba a number"
         # https://code.google.com/feeds/issues/p/googleappengine/
         feed = feedparser.parse(self.show_url(bugId), agent=useragent())
-        print(feed)
         if not feed.entries: return {}
-        print(list(feed.entries[0].keys()))
         """[u'issues_label', 'updated_parsed', 'links', u'issues_owner', u'issues_closeddate', 'href', u'issues_status', 'id', u'issues_uri', 'published_parsed', 
              'title', u'issues_id', u'issues_stars', 'content', 'title_detail', u'issues_state', 'updated', 'link', 'authors', 'author_detail', 'author', 
              u'issues_username', 'summary', 'published']"""
@@ -554,8 +552,7 @@ class BugManager(Pdod):
         }
 
     def __init__(self):
-        Pdod.__init__(self, os.path.join(getdatadir() + os.sep + 'plugs' + os.sep \
-+ 'bugtracker', 'bugtracker'))
+        Pdod.__init__(self, os.path.join(getdatadir(), 'plugs', 'extra', 'bugtracker', 'trackers'))
         self.load()
 
     def add(self, bot, ievent, type, url):
@@ -604,13 +601,16 @@ class BugManager(Pdod):
             self.save()
         self.instances[botname][channel] = self.types[data[1]](data[0], data[2])
 
-    # "internals"
+    ## bug-info command
+
     def handle_tracker_info(self, bot, ievent):
         if not self.check(bot, ievent):
             ievent.reply('no bugtracker active on %s' % ievent.channel)
         else:
             data = self.data[bot.cfg.name][ievent.channel]
             ievent.reply('bugtracker type: %s .. url: %s .. autoshow: %s' % (data[1], data[0], str(data[2])))
+
+    ## bug-set command
     
     def handle_tracker_set(self, bot, ievent):
         if len(ievent.args) != 2:
@@ -622,6 +622,8 @@ class BugManager(Pdod):
         except AssertionError as e:
             ievent.reply('error: %s' % e) 
 
+    ## bug-autoshow command
+
     def handle_autoshow(self, bot, ievent):
         if not self.check(bot, ievent):
             ievent.reply('no bugtracker configured')
@@ -634,7 +636,8 @@ class BugManager(Pdod):
         self.save()
         ievent.reply('autoshow is now %s' % str(self.data[bot.cfg.name][ievent.channel][2]))
 
-    # proxies
+    ## proxies
+
     def handle_close(self, bot, ievent):
         if not self.check(bot, ievent):
             ievent.reply('no bugtracker configured')
@@ -648,11 +651,8 @@ class BugManager(Pdod):
         if not self.check(bot, ievent):
             ievent.reply('no bugtracker configured')
             return
-        #try:
         self.instances[bot.cfg.name][ievent.channel].handle_comments(bot, ievent)
-        #except Exception, e:
-        #    ievent.reply('failed to get bug information: %s' % str(e))
-    
+
     def handle_list(self, bot, ievent):
         if not self.check(bot, ievent):
             ievent.reply('no bugtracker configured')
@@ -684,6 +684,8 @@ class BugManager(Pdod):
             handle_exception()
             ievent.reply('failed to fetch bug information: %s' % str(e))
 
+    ## cb_privmsg callback
+
     def cb_privmsg(self, bot, ievent):
         if bot.cfg.name not in self.instances:
             return 0
@@ -700,6 +702,8 @@ bugtrackers = BugManager()
 def init():
     callbacks.add('PRIVMSG', bugtrackers.cb_privmsg)
 
+## register stuff
+
 cmnds.add('bug-autoshow', bugtrackers.handle_autoshow, ['OPER'])
 examples.add('bug-autoshow', 'toggle automatic retrieval of bug information', 'bug-autoshow')
 cmnds.add('bug-close', bugtrackers.handle_close, ['OPER', 'BUGS'], threaded=True)
@@ -711,6 +715,7 @@ examples.add('bug-list', 'list all open bugs', 'bug-list')
 cmnds.add('bug', bugtrackers.handle_show, ['USER'], threaded=True)
 examples.add('bug', 'show a bug', 'bug 42')
 cmnds.add('bug-info', bugtrackers.handle_tracker_info, ['BUGSOPER', 'OPER'])
+examples.add("bug-info", "get information on a bugtracker", "bug-info")
 cmnds.add('bug-set', bugtrackers.handle_tracker_set, ['BUGSOPER', 'OPER'])
 examples.add('bug-set', 'set a bugtracker for the channel', 'bug-set googletracker https://code.google.com/feeds/issues/p/fbfbot/issues/full')
  
