@@ -51,7 +51,7 @@ def getRpcClient(sInfo):
 
     return rpc_clients[sInfo["name"]]
 
-## confluence-add_confluence_server command
+## confluence-addserver command
 
 def handle_add_confluence_server(bot, ievent):
     """ configure a new confluence server; syntax: add_confluence_server [server name] [url] [username] [password] """
@@ -74,8 +74,10 @@ def handle_add_confluence_server(bot, ievent):
     cfg.save()
 
     ievent.reply("Added confluence server %s" % server["name"])
-cmnds.add("add_confluence_server", handle_add_confluence_server, ["OPER"])
-examples.add("add_confluence_server", "add a confluence server", "add_confluence_server FireBreath http://confluence.firebreath.org myuser mypassword")
+cmnds.add("confluence-addserver", handle_add_confluence_server, ["OPER"])
+examples.add("confluence-addserver", "add a confluence server", "confluence-addserver FireBreath http://confluence.firebreath.org myuser mypassword")
+
+## confluence-delserver command
 
 def handle_del_confluence_server(bot, ievent):
     """ remove a confluence server; syntax: del_confluence_server """
@@ -92,8 +94,11 @@ def handle_del_confluence_server(bot, ievent):
         ievent.reply("Deleted confluence server %s" % serverName)
     else:
         ievent.reply("Unknown confluence server %s" % serverName)
-cmnds.add("del_confluence_server", handle_del_confluence_server, ["OPER"])
-examples.add("del_confluence_server", "del a confluence server", "del_confluence_server FireBreath http://confluence.firebreath.org myuser mypassword")
+
+cmnds.add("confluence-delserver", handle_del_confluence_server, ["OPER"])
+examples.add("confluence-delserver", "del a confluence server", "confluence-delserver FireBreath http://confluence.firebreath.org myuser mypassword")
+
+## confluence-enableserver command
 
 def handle_confluence_enable_server(bot, ievent):
     """ choose the confluence server for lookups in the current channel; syntax: handle_confluence_enable_server [server] """
@@ -112,8 +117,9 @@ def handle_confluence_enable_server(bot, ievent):
     cfg.data["channels"][ievent.channel] = serverName
     cfg.save()
     ievent.reply("enabled confluence searches from this channel for server %s" % serverName)
-cmnds.add("confluence_enable_server", handle_confluence_enable_server, ["OPER"])
-examples.add("confluence_enable_server", "enable searching confluence from the channel", "confluence_enable_server confluenceserver")
+
+cmnds.add("confluence-enableserver", handle_confluence_enable_server, ["OPER"])
+examples.add("confluence-enableserver", "enable searching confluence from the channel", "confluence-enableserver confluenceserver")
 
 ## confluence-disable command
 
@@ -125,10 +131,10 @@ def handle_confluence_disable(bot, ievent):
 
     del cfg.data["channels"][ievent.channel]
     ievent.reply("disabled confluence searching from this channel")
-cmnds.add("confluence_disable", handle_confluence_disable, ["OPER"])
-examples.add("confluence_disable", "disable lookups for confluence in the current channel", "confluence_disable")
+cmnds.add("confluence-disable", handle_confluence_disable, ["OPER"])
+examples.add("confluence-disable", "disable lookups for confluence in the current channel", "confluence-disable")
 
-## wiki command
+## confluence-wiki command
 
 def handle_confluence_search(bot, ievent):
 
@@ -162,5 +168,5 @@ def handle_confluence_search(bot, ievent):
         tinyurl = tinyurl[0] if tinyurl else page["url"]
         ievent.reply('"%s": %s' % (page["title"], tinyurl))
 
-cmnds.add("wiki", handle_confluence_search, ["OPER", "USER", "GUEST"])
-examples.add("wiki", "perform a lookup in the selected confluence instance", "wiki #5 some search text")
+cmnds.add("confluence-wiki", handle_confluence_search, ["OPER", "USER", "GUEST"])
+examples.add("confluence-wiki", "perform a lookup in the selected confluence instance", "confluence-wiki #5 some search text")
