@@ -40,12 +40,14 @@ import logging
 import pickle
 
 ## check for pycrypto dependancy
+got = False
 
 try:
-  import Crypto.Cipher.Blowfish
-  import Crypto.Cipher.AES
-except ImportError:
-  raise RequireError("PyCrypto is required for FiSH. Please install this library if you want to use this plug")
+    import Crypto.Cipher.Blowfish
+    import Crypto.Cipher.AES
+    got = True
+except ImportError: 
+    raise RequireError("PyCrypto is required for FiSH. Please install this library if you want to use this plug")
 
 ## defines
 
@@ -63,12 +65,14 @@ class KeyStore(Persist):
 ## make sure we get loaded
 
 def dummycb(bot, event): pass
+
 callbacks.add("START", dummycb)
 
 ## plugin
 
 def init():
   """ Init """
+  if not got: raise RequireError("PyCrypto is required for FiSH. Please install this library if you want to use this plug")
   if cfg.enable:
     inputmorphs.add(fishin)
     outputmorphs.add(fishout)
@@ -237,8 +241,6 @@ def handle_fish(bot, event):
     key.save()
     event.reply("Deleted key %s" % args[1])
   
-
-
 #### irccrypt module
 
 ##
@@ -316,13 +318,6 @@ ___version__ = "0.1.1"
 import base64
 import hashlib
 from math import log
-try:
-    import Crypto.Cipher.Blowfish
-    import Crypto.Cipher.AES
-except ImportError:
-    print("This module requires PyCrypto / The Python Cryptographic Toolkit.")
-    print("Get it from http://www.dlitz.net/software/pycrypto/.")
-    raise
 from os import urandom
 import struct
 import time
@@ -436,6 +431,7 @@ class Blowfish:
     
     def __init__(self, key=None):
         if key:
+            import Crypto.Cipher.Blowfish
             self.blowfish = Crypto.Cipher.Blowfish.new(key)
 
     def decrypt(self, data):
@@ -449,6 +445,7 @@ class BlowfishCBC:
     
     def __init__(self, key=None):
         if key:
+            import Crypto.Cipher.Blowfish
             self.blowfish = Crypto.Cipher.Blowfish.new(key)
 
     def decrypt(self, data):
@@ -461,6 +458,7 @@ class BlowfishCBC:
 class AESCBC:
     
     def __init__(self, key):
+        import Crypto.Cipher.AES
         self.aes = Crypto.Cipher.AES.new(key)
 
     def decrypt(self, data):
@@ -582,6 +580,7 @@ p_dh1080 = int('FBE1022E23D213E8ACFA9AE8B9DFAD'
                '83EB68FA07A77AB6AD7BEB618ACF9C'
                'A2897EB28A6189EFA07AB99A8A7FA9'
                'AE299EFA7BA66DEAFEFBEFBF0B7D8B', 16)
+
 q_dh1080 = (p_dh1080 - 1) / 2 
 
 
