@@ -1,4 +1,4 @@
-# fbf/plugs/common/hubbub.py
+# fbf/plugs/extra/hubbub.py
 #
 #
 
@@ -10,6 +10,7 @@
 
 ## fbf imports
 
+from fbf.lib.callbacks import callbacks
 from fbf.lib.commands import cmnds
 from fbf.lib.examples import examples
 from fbf.lib.persist import Persist, PlugPersist
@@ -23,11 +24,14 @@ from fbf.utils.exception import handle_exception
 from fbf.lib.fleet import getfleet
 from fbf.lib.channelbase import ChannelBase
 from fbf.utils.url import posturl
-from fbf.lib.errors import NoSuchBotType
+from fbf.lib.errors import NoSuchBotType, RequireError
 from fbf.lib.threads import start_new_thread
 from fbf.lib.datadir import getdatadir
 from fbf.lib.fbfimport import import_byfile
 from fbf.imports import getfeedparser
+from fbf.api.hooks import get_hooks, post_hooks
+from fbf.utils.creds import getcredsmod
+
 feedparser = getfeedparser()
 
 ## basic imports
@@ -39,34 +43,33 @@ import urllib.parse
 import uuid
 import os
 import time
+import socket
 
 ## subscribe function
 
-def subscribe(url):
+def subscribe(url, host):
     """ subscribe to an hubbub feed. """
     subscribe_args = {
-        'hub.callback': urllib.parse.urljoin('https://fbfbot.appspot.com', '/hubbub'),
+        'hub.callback': urllib.parse.urljoin('https://', host, '/hubbub'),
         'hub.mode': 'subscribe',
         'hub.topic': url,
         'hub.verify': 'async',
         'hub.verify_token': str(uuid.uuid4()),
     }
     headers = {}
-    try:
-        credentials = import_byfile("credentials", getdatadir() + os.sep + "config" + os.sep + "credentials.py")
-    except IOError: logging.error("missing %s" % getdatadir() + os.sep + "config" + os.sep + "credentials.py") ; return
+    credentials = getcredsmod(doraise=True)
     if credentials.HUB_CREDENTIALS:
-      auth_string = "Basic " + base64.b64encode("%s:%s" % tuple(credentials.HUB_CREDENTIALS))
+      auth_string = "Basic " + str(base64.b64encode(bytes("%s:%s" % tuple(credentials.HUB_CREDENTIALS), "utf-8")), "utf-8")
       headers['Authorization'] = auth_string
-    logging.warn("hubbub - subscribe - trying %s (%s)" % (credentials.HUB_URL, url))
-    logging.warn("hubbub - subscribe - %s" % str(headers))
+    logging.warn("subscribe - trying %s (%s)" % (credentials.HUB_URL, url))
+    logging.warn("subscribe - %s" % str(headers))
     response = posturl(credentials.HUB_URL, headers, subscribe_args)
     return response
 
 ## tinyurl import
 
 try:
-    from fbf.plugins.tinyurl import get_tinyurl
+    from fbf.utils.tinyurl import get_tinyurl
 except ImportError:
     def get_tinyurl(url):
         return [url, ]
@@ -92,6 +95,36 @@ class NoSuchFeed(Exception):
     """ there is no such feed in the feed database. """
     pass
 
+## hubbub_get function
+
+def hubbub_get(bot, event):
+    logging.warn('incoming GET')
+    #print dir(event.handler)
+    #print dir(event.request)
+    #print event.request
+    #print event.request.arguments
+    if event.request.arguments['hub.mode'][0] == 'unsubscribe':
+        event.request.headers['Content-Type'] = 'text/plain'
+        event.reply(event.request.arguments['hub.challenge'][0])
+        event.finish()
+        return  
+    if event.request.arguments['hub.mode'][0] != 'subscribe': event.handler.send_error(400) ; return
+    event.request.headers['Content-Type'] = 'text/plain'
+    event.reply(event.request.arguments['hub.challenge'][0])
+    event.finish()
+
+## hubbub_post function
+
+def hubbub_post(bot, event):
+    """Handles new content notifications."""
+    logging.warn("incoming POST")
+    try: watcher.incoming(event.request.body)
+    except IndexError: logging.error("hubbub plugin did not load properly")
+    except Exception as ex:
+        handle_exception()
+        event.handler.send_error(500)
+    event.finish()
+
 ## HubbubItem class
 
 class HubbubItem(Persist):
@@ -100,7 +133,7 @@ class HubbubItem(Persist):
 
 
     def __init__(self, name, url="", owner="", itemslist=['title', 'link'], watchchannels=[], running=1):
-        filebase = getdatadir() + os.sep + 'plugs' + os.sep + 'fbf.plugs.wave.hubbub' + os.sep + name
+        filebase = getdatadir() + os.sep + 'plugs' + os.sep + 'fbf.plugs.extra.hubbub' + os.sep + name
         Persist.__init__(self, filebase + os.sep + name + '.core')
         if not self.data: self.data = {}
         self.data = LazyDict(self.data)
@@ -128,14 +161,14 @@ class HubbubItem(Persist):
         """ get data of rss feed. """
         url = self.data['url']
         if not url:
-            logging.warn("hubbub - %s doesnt have url set" % self.data.name)
+            logging.warn("%s doesnt have url set" % self.data.name)
             return []
         result = feedparser.parse(url, agent=useragent())
-        logging.debug("hubbub - fetch - got result from %s" % url)
-        if result and 'bozo_exception' in result: logging.info('hubbub - %s bozo_exception: %s' % (url, result['bozo_exception']))
+        logging.debug("got result from %s" % url)
+        if result and 'bozo_exception' in result: logging.info('%s bozo_exception: %s' % (url, result['bozo_exception']))
         try:
             status = result.status
-            logging.info("hubbub - status is %s" % status)
+            logging.info("status is %s" % status)
         except AttributeError: status = 200
         if status != 200 and status != 301 and status != 302: raise RssStatus(status)
         return result.entries
@@ -149,12 +182,13 @@ class HubbubWatcher(PlugPersist):
         index of feed names.
     """
 
-    def __init__(self, filename):
+    def __init__(self, filename, host):
         PlugPersist.__init__(self, filename)
-        if not self.data: self.data = {}
+        if not self.data: self.data = LazyDict()
         if 'names' not in self.data: self.data['names'] = []
         if 'urls' not in self.data: self.data['urls'] = {}
         if 'feeds' not in self.data: self.data['feeds'] = {}
+        if 'host' not in self.data: self.data['host'] = host
         self.feeds = {}
 
     def add(self, name, url, owner):
@@ -192,7 +226,7 @@ class HubbubWatcher(PlugPersist):
         for line in data.split('\n'):
             try: (name, url) = line.split()
             except ValueError:
-                logging.debug("hubbub - cloneurl - can't split %s line" % line)
+                logging.debug("can't split %s line" % line)
                 continue
             if url.endswith('<br>'): url = url[:-4]
             self.add(name, url, auth)
@@ -208,22 +242,20 @@ class HubbubWatcher(PlugPersist):
             item.data.running = 1
             item.data.stoprunning = 0
             item.save()
-            subscribe(item.data['url'])
-        logging.info('hubbub - started %s watch' % name)
+            subscribe(item.data['url'], self.data.host)
+        logging.info('started %s watch' % name)
 
     def work(self, botname, type, channel, entries, url, *args, **kwargs):
+        logging.debug("in work .. %s" % str(entries))
         try:
             item = self.byurl(url)
             name = item.data.name
             try:
                 fleet = getfleet()
                 bot = fleet.byname(botname)
-                if not bot and type:
-                    bot = fleet.makebot(type, botname)
-                if not bot:
-                    bot = fleet.makebot('xmpp', botname)
-            except NoSuchBotType as ex: logging.warn("hubbub - %s" % str(ex)) ; return
-            if not bot: logging.error("hubbub - can't find %s bot in fleet" % type) ; return
+                if not bot: logging.warn("can't find %s bot in fleet" % botname) ; return
+            except NoSuchBotType as ex: logging.warn("%s" % str(ex)) ; return
+            if not bot: logging.error("can't find %s bot in fleet" % type) ; return
             res2 = entries
             if not res2: logging.info("no updates for %s (%s) feed available" % (item.data.name, channel)) ; return
             if item.markup.get(jsonstring([name, channel]), 'reverse-order'): res2 = res2[::-1]
@@ -243,19 +275,19 @@ class HubbubWatcher(PlugPersist):
         """ process incoming hubbub data. """
         result = feedparser.parse(data)
         url = find_self_url(result.feed.links)
-        logging.info("hubbub - in - %s - %s" % (url, data))
+        logging.debug("%s - %s" % (url, data))
         try:
             item = self.byurl(url)
-            if not item: logging.warn("hubbub - can't find feed for %s" % url) ; return
-            if not item.data.running: logging.warn("hubbub - %s is not in running mode" % item.data.url) ; return
+            if not item: logging.warn("can't find feed for %s" % url) ; return
+            if not item.data.running: logging.warn("%s is not in running mode" % item.data.url) ; return
             if not item.data.url or item.data.url == 'urlnotset':
                 item.data.url = url
                 item.save()
             if item:
                 loopover = item.data.watchchannels
                 name = item.data.name
-            else: logging.warn("hubbub - can't find %s item" % url) ; return
-            logging.debug("loopover in %s peek is: %s" % (name, loopover))
+            else: logging.warn("can't find %s item" % url) ; return
+            logging.warn("loopover in %s peek is: %s" % (name, loopover))
             counter = 1
             for i in loopover:
                 if len(i) == 3:
@@ -263,12 +295,13 @@ class HubbubWatcher(PlugPersist):
                     except:
                         try: (botname, type, channel) = loads(i)
                         except:
-                            logging.info('hubbub - %s is not in the format (botname, bottype, channel)' % str(item))
+                            logging.warn('%s is not in the format (botname, bottype, channel)' % str(item))
                             continue
                 else:
-                    logging.debug('hubbub - %s is not in the format (botname, bottype, channel)' % item.data.url)
+                    logging.warn('%s is not in the format (botname, bottype, channel)' % item.data.url)
                     continue
                 counter += 1
+                start_new_thread(self.work, (botname, type, channel, result.entries, url), {"_countdown": counter})
         except Exception as ex: handle_exception(txt=url)
         return True
 
@@ -333,7 +366,7 @@ class HubbubWatcher(PlugPersist):
                         else: resultstr += "%s - " % ii
                     else: resultstr += "%s - " % ii.strip()
                 except (KeyError, AttributeError) as ex:
-                    logging.info('hubbub - %s - %s' % (name, str(ex)))
+                    logging.info('%s - %s' % (name, str(ex)))
                     continue
             resultstr = resultstr[:-3]
             if resultstr: result += "%s %s " % (resultstr, sep)
@@ -425,7 +458,7 @@ class HubbubWatcher(PlugPersist):
         item.data.stoprunning = 0
         item.save()
         watcher.watch(name)
-        logging.debug("hubbub - started %s feed in %s channel" % (name, channel))
+        logging.debug("started %s feed in %s channel" % (name, channel))
         return True
 
     def stop(self, botname, type, name, channel):
@@ -446,14 +479,23 @@ class HubbubWatcher(PlugPersist):
         except ValueError: return False
         return True
 
-    def clone(self, botname, type, newchannel, oldchannel):
-        """ clone feeds over to a new wave. """
-        feeds = self.getfeeds(oldchannel, botname)
-        logging.debug("hubbub - clone - %s - %s - %s - %s - %s" % (botname, type, newchannel, oldchannel, feeds))
-        for feed in feeds:
-            self.stop(botname, type, feed, oldchannel)
-            self.start(botname, type, feed, newchannel)
-        return feeds
+## plugin initialisation
+
+def init():
+    get_hooks.register("/api/hubbub", hubbub_get)
+    post_hooks.register("/api/hubbub", hubbub_post)
+
+## plugins shutdown
+
+def shutdown():
+    get_hooks.unregister("/api/hubbub")
+    post_hooks.unregister("/api/hubbub")
+
+## dummycb to make sure this plugin loads on startup
+
+def dummycb(bot, event): pass
+
+callbacks.add("START", dummycb)
 
 ## work function
 
@@ -463,7 +505,7 @@ def work(botname, type, channel, result, item, *args, **kwargs):
 
 ## the watcher object
 
-watcher = HubbubWatcher('hubbub')
+watcher = HubbubWatcher('hubbub', socket.gethostname())
 
 ## size function
 
@@ -483,23 +525,11 @@ def handle_hubbubsubscribe(bot, event):
         if not url.startswith('http://'): event.reply('%s doesnt start with "http://"' % url)
         if name not in watcher.data['urls']: watcher.add(name, url, event.channel)
         if not watcher.byname(name): watcher.add(name, url, event.channel)
-        response = subscribe(url)
+        response = subscribe(url, socket.gethostname())
         event.reply("subscription send: %s - %s" % (url, response.status))
 
 cmnds.add('hb-subscribe', handle_hubbubsubscribe, ['USER',])
-examples.add('hb-subscribe', 'subscribe to a feed', 'hb-subscribe fbf-hg http://code.google.com/feeds/p/fbf/hgchanges/basi')
-
-## hb-clone command
-
-def handle_hubbubclone(bot, event):
-    """ arguments: <channel> - clone the feeds running in a channel. """
-    if not event.rest: event.missing('<channel>') ; return
-    feeds = watcher.clone(bot.cfg.name, bot.type, event.channel, event.rest)
-    event.reply('cloned the following feeds: ', feeds)
-    bot.say(event.rest, "this wave is continued in %s" % event.url)
- 
-cmnds.add('hb-clone', handle_hubbubclone, 'USER')
-examples.add('hb-clone', 'clone feeds into new channel', 'hb-clone #dunkbots')
+examples.add('hb-subscribe', 'subscribe to a feed', 'hb-subscribe fbf https://github.com/feedbackflow/fbfbot/commits/master.atom')
 
 ## hb-add command
 
@@ -507,15 +537,15 @@ def handle_hubbubadd(bot, ievent):
     """ arguments: <feedname> <url> - add a hubbub item (name/url combo). """
     try: (name, url) = ievent.args
     except ValueError: ievent.missing('<name> <url>') ; return
-    result = subscribe(url)
-    if not result: ievent.reply("can't subscribe to feed") ; return
+    try: result = subscribe(url, socket.gethostname())
+    except RequireError as ex: ievent.reply(str(ex)) ; return
     if int(result.status) > 200 and int(result.status) < 300:
        watcher.add(name, url, ievent.userhost)
        ievent.reply('%s feed added' % name)
     else: ievent.reply('%s feed NOT added. status code is %s' % (name, result.status))
 
 cmnds.add('hb-add', handle_hubbubadd, 'USER')
-examples.add('hb-add', 'hubbub-add <name> <url> to the watcher', 'hb-add fbf-hg http://code.google.com/feeds/p/fbf/hgchanges/basic')
+examples.add('hb-add', 'hubbub-add <name> <url> to the watcher', 'hb-add fbf https://github.com/feedbackflow/fbfbot/commits/master.atom')
 
 ## hb-watch command
 
@@ -539,7 +569,7 @@ def handle_hubbubwatch(bot, ievent):
 cmnds.add('hb-watch', handle_hubbubwatch, 'USER')
 examples.add('hb-watch', 'hubbub-watch <name> [seconds to sleep] .. go watching <name>', 'hb-watch gozerbot')
 
-## hubbub-start command
+## hb-start command
 
 def handle_hubbubstart(bot, ievent):
     """ arguments: <list of feeds> - start sending feeds to an user or channel. """
@@ -555,13 +585,6 @@ def handle_hubbubstart(bot, ievent):
                 ievent.chan.data.feeds.append(name)
                 ievent.chan.save()
         else: cantstart.append(name)
-    if bot.type == "wave":
-        wave = ievent.chan
-        if wave and wave.data:
-            logging.debug("feed running in %s: %s" % (ievent.title, wave.data.feeds))
-            if wave.data.loud:
-                try: ievent.set_title("FBFBOT - %s - #%s" % (' - '.join(wave.data.feeds), str(wave.data.nrcloned)))
-                except Exception as ex: handle_exception()
     if started: ievent.reply('started: ', started)
     else: ievent.reply("sorry can't start: ", cantstart)
 
@@ -628,7 +651,7 @@ def handle_hubbubchannels(bot, ievent):
 cmnds.add('hb-channels', handle_hubbubchannels, ['OPER', ])
 examples.add('hb-channels', 'hb-channels <name> .. show channels', 'hb-channels gozerbot')
 
-## hb-addchannel
+## hb-addchannel command
 
 def handle_hubbubaddchannel(bot, ievent):
     """ arguments: <feedname> [<botname>] [<bottype>] <channel> - add a channel to  hubbub feed. """
@@ -937,9 +960,11 @@ def handle_hubbubfeeds(bot, ievent):
 cmnds.add('hb-feeds', handle_hubbubfeeds, ['USER', 'GUEST'])
 examples.add('hb-feeds', 'hb-feeds <name> .. show what feeds are running in a channel', '1) hb-feeds 2) hb-feeds #dunkbots')
 
+## hb-register command
+
 def handle_hubbubregister(bot, ievent):
     """ arguments: <feedname> <url> - register a url and start the feed in one pass. """
-    target = ievent.waveid or ievent.channel
+    target = ievent.channel
     if len(ievent.args) > 2: ievent.reply("feed name needs to be 1 word.") ; return
     try: (name, url) = ievent.args
     except ValueError:
@@ -957,8 +982,8 @@ def handle_hubbubregister(bot, ievent):
         else: ievent.reply("i don't know a %s feed. please enter name and url." % name)
         return
     if not url.startswith("http"): ievent.reply("the feedurl needs to start with http(s)://") ; return
-    result = subscribe(url)
-    if not result: ievent.reply("can't subscribe") ; return
+    try: result = subscribe(url, socket.gethostname())
+    except RequireError as ex: ievent.reply(str(ex)) ; return
     if int(result.status) > 200 and int(result.status) < 300:
         if watcher.add(name, url, ievent.userhost):
             watcher.start(bot.cfg.name, bot.type, name, target)
@@ -971,4 +996,4 @@ def handle_hubbubregister(bot, ievent):
         ievent.reply('feed %s NOT added. Status code is %s. please check if the feed is valid.' % (name, result.status))
 
 cmnds.add('hb-register', handle_hubbubregister, ['USER', 'GUEST'])
-examples.add('hb-register', 'hb-register .. register url and start it in one pass', 'hb-register hgrepo http://code.google.com/feeds/p/fbf/hgchanges/basic')
+examples.add('hb-register', 'hb-register .. register url and start it in one pass', 'hb-register fbfrepo https://github.com/feedbackflow/fbfbot/commits/master.atom')
