@@ -95,12 +95,15 @@ class OverFlowAPI(object):
         url = 'http://api.stackoverflow.com/1.0%s/%s?body=true&pagesize=%s' % (mount, urllib.parse.urlencode(options), size)
         if self.api_key is not None:
             url += '&key=%s' % self.api_key
-        content = io.StringIO(geturl2(url, timeout=15))
-        return gzip.GzipFile(fileobj=content).read()
+        content = geturl2(url, timeout=15, bytes=True)
+        contentstream = io.BytesIO(content)
+        return str(gzip.GzipFile(fileobj=contentstream).read(), "utf-8")
   
     def timeline(self, target, size=30):
         json_data = self.api("/users/%s/timeline" % target, size)
-        return json.loads(json_data)['user_timelines']
+        try: res = json.loads(json_data)['user_timelines']
+        except ValueError as ex: logging.error("can't parse %s" % json_data) ; res = None
+        return res
 
     def answers(self, target, size=30):
         json_data = self.api("/answers/%s/" % target, size)
