@@ -42,7 +42,7 @@ from fbf.lib.datadir import getdatadir
 from fbf.lib.channelbase import ChannelBase
 from fbf.imports import getfeedparser, getjson
 from fbf.lib.cache import get, set, delete
-from fbf.lib.runner import threadrunner
+from fbf.lib.runner import urlrunner
 from fbf.contrib.natural.date import duration, delta
 
 ## tinyurl import
@@ -175,16 +175,20 @@ sleeptime=15*60, running=0):
         for item in itemslist:
             try: d[item] = data[item]
             except (KeyError, TypeError): continue
-        digest = hashlib.md5(str(d)).hexdigest()
+        dstr = str(d)
+        digest = hashlib.md5(bytes(dstr, "utf-8")).hexdigest()
         return digest in self.data.seen
 
     def setseen(self, data, itemslist=['title', 'link'], length=200):
         d = {}
         got = False
         for item in itemslist:
-            try: d[item] = data[item]
-            except KeyError: continue
-        digest = hashlib.md5(str(d, "utf-8")).hexdigest()
+            try: d[item] = str(data[item], "utf-8")
+            except (KeyError, TypeError):
+                try: d[item] = data[item]
+                except KeyError: continue
+        dstr = str(d)
+        digest = hashlib.md5(bytes(dstr, "utf-8")).hexdigest()
         if digest not in self.data.seen: self.data.seen.insert(0, digest) ; got = True
         self.data.seen = self.data.seen[:self.data.length]
         return got
@@ -287,6 +291,7 @@ sleeptime=15*60, running=0):
             loopover = self.data.watchchannels
             logging.info("loopover in %s deliver is: %s" % (self.data.name, loopover))
             nritems = 0
+            done = []
             for item in loopover:
                 logging.info("item is: %s" % str(item))
                 if not item: continue
@@ -324,7 +329,8 @@ sleeptime=15*60, running=0):
                     if hashtag: response += " %s" % hashtag
                     try: bot.say(nick or channel, response, how=how, speed=-1, **{'headlines': True}) ; nritems += 1
                     except Exception as ex: handle_exception()
-            logging.warn("DELIVERED %s %s items on: %s" % (nritems, name, str(loopover)))
+                done.append(str(item))
+            if nritems: logging.warn("DELIVERED %s %s items on: %s" % (nritems, name, ", ".join(done)))
             return nritems
         except Exception as ex: handle_exception(txt=name) ; return str(ex)
 
@@ -470,11 +476,12 @@ class Rssdict(PlugPersist):
         rssitem.data.stoprunning = 0
         rssitem.updateseen()
         rssitem.save()
+        global runners
+        global sleeptime
+        global worksleeptime
         if not name in runners.data: runners.data[name] = "bla" ; runners.save()
-        sleeptime.data[name] = sleepsec
-        worksleeptime.data[name] = sleepsec
-        sleeptime.save()
-        worksleeptime.save()
+        if name not in sleeptime.data: sleeptime.data[name] = sleepsec ; sleeptime.save()
+        if name not in worksleeptime.data: worksleeptime.data[name] = sleepsec ; worksleeptime.save()
         logging.warn('%s started' % name)
 
 ## Rsswatcher class
@@ -560,6 +567,7 @@ class Rsswatcher(Rssdict):
         elif checked: ret = "checked: %s" % checked
         elif len(result): ret = "fetched: %s" % len(result)
         else: ret = "none done"
+        logging.info("%s - %s" % (name, ret))
         return ret
        
     def ownercheck(self, name, userhost):
@@ -574,8 +582,6 @@ class Rsswatcher(Rssdict):
         """ not implemented yet. """
         sleeptime.data[name] = interval
         sleeptime.save()
-        worksleeptime.data[name] = interval
-        worksleeptime.save()
 
     def stopwatchers(self):
         """ stop all watcher threads. """
@@ -708,7 +714,7 @@ class Rsswatcher(Rssdict):
         rssitem.data.running = 1
         rssitem.data.stoprunning = 0
         rssitem.save()
-        #if name not in self.runners(): watcher.watch(name)
+        if name not in self.runners(): watcher.watch(name)
         logging.warn("started %s feed in %s channel" % (name, channel))
         return True
 
@@ -731,7 +737,7 @@ class Rsswatcher(Rssdict):
             self.start(botname, bottype, feed, newchannel)
         return feeds
 
-## more global defines 
+## more defines 
 
 watcher = Rsswatcher('rss')
 urls = PlugPersist('urls')
@@ -739,17 +745,14 @@ etags = PlugPersist('etags')
 
 assert(watcher)
 
-## size function
-
-def size():
-    return "%s (feeds)" % watcher.size()
-
-## dosync function
+## dummy callback to get plugin loaded on START
 
 def dummycb(bot, event): pass
 
 callbacks.add('START', dummycb)
 
+## dosync function
+
 def dosync(feedname):
     """ main level function to be deferred by periodical. """
     try:
@@ -767,9 +770,11 @@ def shouldpoll(name, curtime):
     except KeyError: lp = lastpoll.data[name] = time.time() ; lastpoll.sync()
     global worksleeptime
     try: st = worksleeptime.data[name]
-    except KeyError: st = worksleeptime.data[name] = 900 ; worksleeptime.sync()
-    logging.debug("pollcheck - %s - %s - remaining %s" % (name, time.ctime(lp), (lp + st) - curtime))
-    if curtime - lp > st: return True
+    except KeyError:
+        try: st = sleeptime.data[name]
+        except KeyError: st = worksleeptime.data[name] = sleeptime.data[name] = 300 ; worksleeptime.sync()
+    logging.info("%s - remaining %.2f" % (name, (lp + st) - curtime))
+    if ((lp + st) - curtime) < 0: logging.info("yes should poll %s" % name) ; return True
 
 ## dodata function
 
@@ -782,26 +787,26 @@ def doperiodical(*args, **kwargs):
     """ rss periodical function. """
     got = False
     curtime = time.time()
-    #sleeptime.save()
+    worksleeptime.save()
     for feed in watcher.data.names:
         if not watcher.shouldpoll(feed, curtime): continue
         lastpoll.data[feed] = curtime
         got = True
         logging.info("launching %s" % feed)
-        threadrunner.put(8, feed, dosync, (feed, ))
-        time.sleep(1)
+        urlrunner.put(5, feed, dosync, feed)
     if got: lastpoll.save()
 
 callbacks.add('TICK60', doperiodical)
 
 ## init function
 
-def init():
+def init_threaded():
     """ initialize the rss plugin. """
-    if not runners.data: start_new_thread(watcher.checkrunners, ())
+    if not runners.data: watcher.checkrunners, ()
     global starttime
     starttime = time.time()
- 
+    #watcher.startwatchers()
+
 ## shutdown function
 
 def shutdown():
@@ -1383,7 +1388,7 @@ def handle_rssseturl(bot, ievent):
 cmnds.add('rss-seturl', handle_rssseturl, ['OPER', ])
 examples.add('rss-seturl', 'set the url of a feed', 'rss-seturl fbfbot https://github.com/feedbackflow/fbfbot/commits/master.atom')
 
-## rss-itemslist
+## rss-itemslist command
 
 def handle_rssitemslist(bot, ievent):
     """ argumetns <feedname> - show list of tokens of feed that are being displayed. """
@@ -1417,7 +1422,7 @@ def handle_rssscan(bot, ievent):
 cmnds.add('rss-scan', handle_rssscan, ['USER', ])
 examples.add('rss-scan', 'get possible tokens of a feed that can be displayed ', 'rss-scan fbfbot')
 
-## rss-feeds
+## rss-feeds command
 
 def handle_rssfeeds(bot, ievent):
     """ arguments: [<channel>] - show what feeds are running in a channel. """
@@ -1447,7 +1452,7 @@ def handle_rsslink(bot, ievent):
 cmnds.add('rss-link', handle_rsslink, ['RSS', 'USER'])
 examples.add('rss-link', 'give link of feeds which title matches search key', 'rss-link fbfbot gozer')
 
-## rss-description commmand
+## rss-description command
 
 def handle_rssdescription(bot, ievent):
     """ arguments: <feedname> <searchtxt> - search descriptions in cached data. """
@@ -1473,7 +1478,7 @@ def handle_rssall(bot, ievent):
 cmnds.add('rss-all', handle_rssall, ['RSS', 'USER'])
 examples.add('rss-all', "give titles of a feed", 'rss-all fbfbot')
 
-## rss-search
+## rss-search command
 
 def handle_rsssearch(bot, ievent):
     """ arguments: <searchtxt> - search in titles of cached data. """
@@ -1485,6 +1490,8 @@ def handle_rsssearch(bot, ievent):
 cmnds.add('rss-search', handle_rsssearch, ['RSS', 'USER'])
 examples.add('rss-search', "search titles of all current feeds", 'rss-search json')
 
+## rss-import command
+
 def handle_rssimport(bot, ievent):
     """ arguments: <url> - import feeds uses OPML. """
     if not ievent.rest: ievent.missing("<url>") ; return
