@@ -51,6 +51,7 @@ def makeircopts(txt=""):
     parser.add_option('-u', '--username', type="string", default=False, dest='username', help="user to auth to server with")
     parser.add_option('-a', '--api', action='store_true', default=False, dest='api',  help="enable api server")
     parser.add_option('', '--apiport', type='string', default=False, dest='apiport', help="port on which the api server will run")
+    parser.add_option('-e', '--enable', action='store_true', default=False, dest='enable', help="enable bot for fleet use")
     if txt: opts, args = parser.parse_args(txt.split())
     else: opts, args = parser.parse_args()
     opts.args = args
@@ -79,6 +80,7 @@ def makesxmppopts(txt=""):
     parser.add_option('-n', '--nick', type='string', default=False, dest='nick',  help="nick of the bot")
     parser.add_option('-a', '--api', action='store_true', default=False, dest='api',  help="enable api server")
     parser.add_option('', '--apiport', type='string', default=False, dest='apiport', help="port on which the api server will run")
+    parser.add_option('-e', '--enable', action='store_true', default=False, dest='enable', help="enable bot for fleet use")
     if txt: opts, args = parser.parse_args(txt.split())
     else: opts, args = parser.parse_args()
     opts.args = args
@@ -171,6 +173,7 @@ def makeircconfig(opts=None, botname=None):
         return cfg          
     if not cfg.channels: cfg.channels = []
     if not cfg.disable: cfg.disable = False
+    if opts.enable: cfg.disable = False ; logging.warn("enabling %s bot in %s" % (botname, cfg.cfile))
     if opts.password: cfg.password = opts.password
     if opts.ipv6: cfg.ipv6 = True
     else: cfg.ipv6 = cfg.ipv6 or False
@@ -221,6 +224,7 @@ def makesxmppconfig(opts=None, botname=None, type="sxmpp"):
     if opts.doregister: cfg.doregister = True ; logging.warn("register mode is enabled")
     else: cfg.doregister = False ; logging.warn("register mode is disabled")
     if not cfg.disable: cfg.disable = False
+    if opts.enable: cfg.disable = 0 ; logging.warn("enabling %s bot in %s" % (botname, cfg.cfile))
     if not cfg.channels: cfg.channels = []
     if opts.user: cfg.user = opts.user
     if not cfg.user: raise NoUserProvided("try giving the -u option to the bot (and maybe -p as well) or run fbf-init and edit %s" % cfg.cfile)
