@@ -25,7 +25,7 @@ def getsource(mod):
     thedir = os.path.abspath(mod.replace(".", os.sep))
     if os.path.isdir(thedir): source = thedir
     if source and os.path.exists(source):
-        logging.info("datadir - source is %s" % source)
+        logging.info("source is %s" % source)
         return source
     if not source:
         try:
@@ -36,5 +36,5 @@ def getsource(mod):
                 import fbf.contrib.pkg_resources as pkg_resources
                 source = pkg_resources.resource_filename(".".join(splitted[:len(splitted)-1]), splitted[-1])
             except ImportError: pass
-    logging.info("datadir - source is %s" % source)
+    logging.info("source is %s" % source)
     return source
