@@ -7,7 +7,7 @@
 ## fbf imports
 
 from .lazydict import LazyDict
-from .generic import fromenc, toenc
+from .generic import fromenc, toenc, printline
 from fbf.lib.errors import URLNotEnabled
 
 ## basic imports
@@ -98,8 +98,8 @@ class Url(LazyDict):
         self.root = urllib.parse.urlunsplit((self.parsed[0], self.parsed[1], "", "", ""))
 
     def fetch(self, *args, **kwargs):
-        self.html = geturl2(self.url)
-        self.status = self.html.info.status
+        self.html = geturl2(self.url, html=True)
+        self.status = self.html.status
         self.txt = striphtml(self.html)
         self.lastpolled = time.time()
         self.parse()
@@ -152,7 +152,7 @@ def geturl(url, version=None):
 
 ## geturl2 function
 
-def geturl2(url, decode=False, timeout=5, bytes=False):
+def geturl2(url, decode=False, timeout=5, bytes=False, html=False):
     """ use urllib2 to fetch an url. """
     global enabled
     if not enabled: raise URLNotEnabled(url)
@@ -162,7 +162,8 @@ def geturl2(url, decode=False, timeout=5, bytes=False):
     opener = urllib.request.build_opener()
     result = opener.open(request, timeout=timeout)
     res = result.read()
-    if not bytes: res = toenc(res, "utf-8")
+    if not bytes: res = fromenc(res, "utf-8")
+    if not bytes and html: res = res.replace("//", "/")
     if not bytes: res = istr(res)
     else: res = ibytes(res)
     info = result.info()
@@ -320,16 +321,19 @@ def get_encoding(data):
 from html.parser import HTMLParser
 
 class MLStripper(HTMLParser):
-    def __init__(self):
+    def __init__(self, *args, **kwargs):
+        HTMLParser.__init__(self, *args, **kwargs)
         self.reset()
         self.fed = []
+
     def handle_data(self, d):
         self.fed.append(d)
+
     def get_data(self):
         return ''.join(self.fed)
 
-def striphtml(html):
+def striphtml(html, strict=False):
     s = MLStripper()
-    s.strict = True
+    s.strict = strict
     s.feed(html)
     return s.get_data()
\ No newline at end of file
